package org.eclipse.jdt.core;

import org.eclipse.jdt.core.util.ICodeAttribute;
import org.eclipse.jdt.core.util.IMethodInfo;
import org.eclipse.jdt.core.util.IClassFileReader;
import java.util.Enumeration;
import java.io.IOException;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import org.apache.tools.ant.BuildException;
import org.eclipse.jdt.internal.antadapter.AntAdapterMessages;
import java.util.zip.ZipFile;
import org.eclipse.jdt.internal.compiler.util.Util;
import org.apache.tools.ant.Task;

public final class CheckDebugAttributes extends Task
{
    private String file;
    private String property;
    
    public CheckDebugAttributes() {
    }
    
    public void execute() throws BuildException {
        if (this.file == null) {
            throw new BuildException(AntAdapterMessages.getString("checkDebugAttributes.file.argument.cannot.be.null"));
        }
        if (this.property == null) {
            throw new BuildException(AntAdapterMessages.getString("checkDebugAttributes.property.argument.cannot.be.null"));
        }
        try {
            boolean hasDebugAttributes = false;
            if (Util.isClassFileName(this.file)) {
                IClassFileReader classFileReader2 = ToolFactory.createDefaultClassFileReader(this.file, 65535);
                hasDebugAttributes = this.checkClassFile(classFileReader2);
            }
            else {
                ZipFile jarFile = null;
                try {
                    jarFile = new ZipFile(this.file);
                }
                catch (ZipException ex) {
                    throw new BuildException(AntAdapterMessages.getString("checkDebugAttributes.file.argument.must.be.a.classfile.or.a.jarfile"));
                }
                finally {
                    if (jarFile != null) {
                        jarFile.close();
                    }
                }
                Enumeration<Object> entries = jarFile.entries();
                while (!hasDebugAttributes && entries.hasMoreElements()) {
                    ZipEntry entry = (ZipEntry)entries.nextElement();
                    if (Util.isClassFileName(entry.getName())) {
                        IClassFileReader classFileReader = ToolFactory.createDefaultClassFileReader(this.file, entry.getName(), 65535);
                        hasDebugAttributes = this.checkClassFile(classFileReader);
                    }
                    else {
                        continue;
                    }
                }
            }
            if (hasDebugAttributes) {
                this.getProject().setUserProperty(this.property, "has debug");
            }
        }
        catch (IOException ex2) {
            throw new BuildException(AntAdapterMessages.getString("checkDebugAttributes.ioexception.occured") + this.file);
        }
        return;
    }
    
    private boolean checkClassFile(IClassFileReader classFileReader) {
        IMethodInfo[] methodInfos = classFileReader.getMethodInfos();
        int i = 0;
        int max = methodInfos.length;
        while (i < max) {
            ICodeAttribute codeAttribute = methodInfos[i].getCodeAttribute();
            if (codeAttribute != null && codeAttribute.getLineNumberAttribute() != null) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    public void setFile(String value) {
        this.file = value;
    }
    
    public void setProperty(String value) {
        this.property = value;
    }
}
